@@ -380,7 +380,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     gweather_info_set_contact_info (gw_applet->gweather_info, contact_info);
 
     gweather_info_set_enabled_providers (gw_applet->gweather_info,
-                                         GWEATHER_PROVIDER_ALL);
+                                         GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_MET_NO);
 
     g_signal_connect (gw_applet->gweather_info, "updated",
                       G_CALLBACK (update_finish), gw_applet);
@@ -494,7 +494,7 @@ update_finish (GWeatherInfo *info, gpointer data)
 
 			 icon = gweather_info_get_icon_name (gw_applet->gweather_info);
 			 if (icon == NULL)
-				 icon = "stock-unknown";
+				 icon = "image-missing";
 	           	 
 			 n = notify_notification_new (message, detail, icon);
 	
