@@ -132,6 +132,7 @@ menu_destroy_all_cb (GSimpleAction *action,
 	GtkBuilder *builder;
 
 	builder = gtk_builder_new ();
+	gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
 	gtk_builder_add_from_resource (builder,
 	                               GRESOURCE_PREFIX "/ui/sticky-notes-delete-all.ui",
 	                               NULL);
@@ -776,7 +777,7 @@ stickynotes_applet_update_tooltips (StickyNotesApplet *self)
 
 	num = g_list_length (self->notes);
 
-	no_notes = g_strdup_printf (ngettext ("%d note", "%d notes", num), num);
+	no_notes = g_strdup_printf (dngettext (GETTEXT_PACKAGE, "%d note", "%d notes", num), num);
 	tooltip = g_strdup_printf ("%s\n%s", _("Show sticky notes"), no_notes);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (self), tooltip);
